@@ -166,13 +166,22 @@ UMLObject* findUMLObject(QString name, UMLObject::ObjectType type)
 
 /**
  * Find or create a document object.
+ * @param type object type
+ * @param inName name of uml object
+ * @param parentPkg parent package
+ * @param comment comment for uml object
+ * @param stereotype stereotype for uml object
+ * @param searchInParentPackageOnly flags to search only in parent package
+ * @param remapParent flag to control remapping of parents if an uml object has been found
+ * @return new object or zero
  */
 UMLObject *createUMLObject(UMLObject::ObjectType type,
                            const QString& inName,
                            UMLPackage *parentPkg,
                            const QString& comment,
                            const QString& stereotype,
-                           bool searchInParentPackageOnly)
+                           bool searchInParentPackageOnly,
+                           bool remapParent)
 {
     QString name = inName;
     UMLDoc *umldoc = UMLApp::app()->document();
@@ -193,19 +202,26 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
         name = name.mid(2);
         parentPkg = logicalView;
     }
-    UMLObject *o = umldoc->findUMLObject(name, type, parentPkg);
     bNewUMLObjectWasCreated = false;
+    UMLObject *o = 0;
     if (searchInParentPackageOnly) {
-        if (o && o->umlPackage() != parentPkg) {
+        o = Model_Utils::findUMLObject(parentPkg->containedObjects(), name, type);
+        if (!o) {
             o = Object_Factory::createNewUMLObject(type, name, parentPkg);
             bNewUMLObjectWasCreated = true;
             bPutAtGlobalScope = false;
         }
+    } else {
+        o = umldoc->findUMLObject(name, type, parentPkg);
     }
     if (o == 0) {
         // Strip possible adornments and look again.
         const bool isConst = name.contains(QRegExp(QLatin1String("^const ")));
         name.remove(QRegExp(QLatin1String("^const\\s+")));
+        const bool isVolatile = name.contains(QRegExp(QLatin1String("^volatile ")));
+        name.remove(QRegExp(QLatin1String("^volatile\\s+")));
+        const bool isMutable = name.contains(QRegExp(QLatin1String("^mutable ")));
+        name.remove(QRegExp(QLatin1String("^mutable\\s+")));
         QString typeName(name);
         bool isAdorned = typeName.contains(QRegExp(QLatin1String("[^\\w:\\. ]")));
         const bool isPointer = typeName.contains(QLatin1Char('*'));
@@ -260,8 +276,12 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
             bNewUMLObjectWasCreated = true;
             bPutAtGlobalScope = false;
         }
-        if (isConst || isAdorned) {
+        if (isConst || isAdorned || isMutable || isVolatile) {
             // Create the full given type (including adornments.)
+            if (isVolatile)
+                name.prepend(QLatin1String("volatile "));
+            if (isMutable)
+                name.prepend(QLatin1String("mutable "));
             if (isConst)
                 name.prepend(QLatin1String("const "));
             o = Object_Factory::createUMLObject(UMLObject::ot_Datatype, name,
@@ -287,7 +307,7 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
         } else {
             o = origType;
         }
-    } else if (parentPkg && !bPutAtGlobalScope) {
+    } else if (parentPkg && !bPutAtGlobalScope && remapParent) {
         UMLPackage *existingPkg = o->umlPackage();
         if (existingPkg != parentPkg && existingPkg != umldoc->datatypeFolder()) {
             if (existingPkg)
@@ -361,7 +381,7 @@ UMLOperation* makeOperation(UMLClassifier *parent, const QString &name)
  * Create a UMLAttribute and insert it into the document.
  * Use the specified existing attrType.
  */
-UMLObject* insertAttribute(UMLClassifier *owner,
+UMLAttribute* insertAttribute(UMLClassifier *owner,
                            Uml::Visibility::Enum scope,
                            const QString& name,
                            UMLClassifier *attrType,
@@ -378,7 +398,7 @@ UMLObject* insertAttribute(UMLClassifier *owner,
     }
     UMLObject *o = owner->findChildObject(name, UMLObject::ot_Attribute);
     if (o) {
-        return o;
+        return o->asUMLAttribute();
     }
 
     UMLAttribute *attr = owner->addAttribute(name, attrType, scope);
@@ -395,7 +415,7 @@ UMLObject* insertAttribute(UMLClassifier *owner,
 /**
  * Create a UMLAttribute and insert it into the document.
  */
-UMLObject* insertAttribute(UMLClassifier *owner, Uml::Visibility::Enum scope,
+UMLAttribute *insertAttribute(UMLClassifier *owner, Uml::Visibility::Enum scope,
                            const QString& name,
                            const QString& type,
                            const QString& comment /* =QString() */,
